/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useContext, useState } from 'react'
import { Store } from '../../Store'
import PersonAddIcon from '@material-ui/icons/PersonAdd';
import styled from 'styled-components'
import Button from '@material-ui/core/Button';
import { putRequest } from '../HelperFunctions/getAxiosConfig'
import LoginModal from './../LoginModal.js'
import Snackbar from '@material-ui/core/Snackbar';
import SignUpModal from './../SignUpModal'
import MuiAlert from '@material-ui/lab/Alert';

function Alert(props) {
    return <MuiAlert elevation={6} variant="filled" {...props} />;
}

export default function FollowButton(props) {

    const { state } = useContext(Store)
    const [loginOpen, setLogin] = useState(false)
    const [successfulLoginOpen, handleSuccessfulLogin] = useState(false)
    const [signUpOpen, setSignUp] = useState(false)

    const handleSignUp = () => {
        setSignUp(!signUpOpen)
    }

    const handleLogin = () => {
        setLogin(!loginOpen)
    }

    const toggleSnackbar = (event, reason) => {
        if (reason === 'clickaway') {
            return;
        }

        handleSuccessfulLogin(false);
    }

    function handleSuccess(data) {
        props.toggleFollowed()
    }

    const handleFollow = (followerID) => {
        if (followerID !== undefined) {
            const url = `/users/${followerID}/follow/`
            putRequest(url, {}, handleSuccess, (error) => { console.log(error) })
        }
    }

    return (
        <React.Fragment>
            <Snackbar open={successfulLoginOpen} autoHideDuration={1000} onClose={toggleSnackbar}
                anchorOrigin={{ vertical: 'top', horizontal: 'center' }}
            >
                <Alert severity="success" style={{ backgroundColor: "#00acc1" }}>Você está conectado(a)!</Alert>
            </Snackbar>
            {/*-------------------------------MODALS---------------------------------------*/}
            <LoginModal open={loginOpen} handleClose={() => setLogin(false)} openSignUp={handleSignUp}
                openSnackbar={() => { handleSuccessfulLogin(true) }}
            />
            <SignUpModal open={signUpOpen} handleClose={handleSignUp} openLogin={handleLogin} />
            {/*----------------------------------------------------------------------------*/}
            {
                state.currentUser.id !== '' ? (
                    <StyledButton contrast={props.contrast} onClick={() => handleFollow(props.followerID)}>
                        <PersonAddIcon style={props.contrast === "" ? {
                            fontSize: "24px",
                            display: "inline-block",
                            verticalAlign: "middle",
                            color: "#00bcd4"
                        } : {
                                fontSize: "24px",
                                display: "inline-block",
                                verticalAlign: "middle",
                                color: "white"
                            }} />
                        SEGUIR
                    </StyledButton>
                )
                    :
                    (
                        <StyledButton contrast={props.contrast} onClick={() => handleLogin(true)}>
                            <PersonAddIcon style={props.contrast === "" ? {
                                fontSize: "24px",
                                display: "inline-block",
                                verticalAlign: "middle",
                                color: "#00bcd4"
                            } : {
                                    fontSize: "24px",
                                    display: "inline-block",
                                    verticalAlign: "middle",
                                    color: "white"
                                }} />
                        SEGUIR
                        </StyledButton>
                    )
            }
        </React.Fragment>
    )
}

export function NoIcon(props) {
    const { state } = useContext(Store)
    const [loginOpen, setLogin] = useState(false)
    const [successfulLoginOpen, handleSuccessfulLogin] = useState(false)
    const [signUpOpen, setSignUp] = useState(false)

    const handleSignUp = () => {
        setSignUp(!signUpOpen)
    }

    const handleLogin = () => {
        setLogin(!loginOpen)
    }

    const toggleSnackbar = (event, reason) => {
        if (reason === 'clickaway') {
            return;
        }

        handleSuccessfulLogin(false);
    }

    const handleFollow = (followerID) => {
        if (followerID !== undefined) {
            const url = `/users/${followerID}/follow/`
            putRequest(url, {}, (data) => { props.toggleFollowed() }, (error) => { console.log(error) })
        }
    }

    return (
        <React.Fragment>
            <Snackbar open={successfulLoginOpen} autoHideDuration={1000} onClose={toggleSnackbar}
                anchorOrigin={{ vertical: 'top', horizontal: 'center' }}
            >
                <Alert severity="success" style={{ backgroundColor: "#00acc1" }}>Você está conectado(a)!</Alert>
            </Snackbar>
            {/*-------------------------------MODALS---------------------------------------*/}
            <LoginModal open={loginOpen} handleClose={() => setLogin(false)} openSignUp={handleSignUp}
                openSnackbar={() => { handleSuccessfulLogin(true) }}
            />
            <SignUpModal open={signUpOpen} handleClose={handleSignUp} openLogin={handleLogin} />
            {/*----------------------------------------------------------------------------*/}
            {
                state.currentUser.id !== '' ? (
                    <NoIconButton onClick={() => handleFollow(props.followableID)}>seguir</NoIconButton>
                )
                    :
                    (
                        <NoIconButton onClick={() => handleLogin(true)}>seguir</NoIconButton>
                    )
            }
        </React.Fragment>
    )
}

const NoIconButton = styled(Button)`
    .MuiButton-label {
        color : #00bcd4 !important;
    }
    background-color : #fff !important;
    border : solid 1px rgba(0,188,212,.85) !important;
    font-size : 14px !important;
    border-radius : 3px !important;
    height : 36px !important;
    min-width : 88px !important;
    vertical-align : middle !important;
    color : #00bcd4 !important;
    align-items : center !important;
    text-align : center !important;
    padding : 0 6px !important;
    margin : 6px 8px !important;
`

const StyledButton = styled(Button)`
    &:hover {
        background-color: ${(props) => props.contrast === "" ? "#fff !important" : "rgba(255,255,0,0.24) !important"};
    }
    background-color: ${(props) => (props.contrast === "" ? "#fff !important" : "black !important")};
    color: ${(props) => (props.contrast === "" ? "#00bcd4 !important" : "yellow !important")};
    border: ${(props) => (props.contrast === "" ? "1px solid #00bcd4 !important" : "1px solid white !important")};
    text-decoration: ${(props) => (props.contrast === "" ? "none !important" : "underline !important")};
    font-size : 14px !important;
    display : inline-block !important;
    position : relative !important;
    cursor : pointer !important;
    height : 36px !important;
    min-width : 88px !important;
    line-height : 36px !important;
    vertical-align : middle !important;
    -webkit-box-align : center !important;
    -webkit-align-items : center !important;
    -ms-grid-row-align : center !important;
    align-items : center !important;
    text-align : center !important;
    border-radius : 3px !important;
    -webkit-user-select : none !important;
    -moz-user-select : none !important;
    -ms-user-select : none !important;
    user-select : none !important;
    padding : 0 6px !important;
    margin : 6px 8px !important;
    white-space : nowrap !important;
    text-transform : uppercase !important;
    font-weight : 500 !important;
    font-style : inherit !important;
    font-variant : inherit !important;
    font-family : inherit !important;
    overflow : hidden !important;
`
