import React from 'react';
import styled from 'styled-components';
import Paper from '@material-ui/core/Paper';
import Grid from '@material-ui/core/Grid';
import Chip from '@material-ui/core/Chip';

export default function FilterSummary
  ({ curriculumComponents, typeOfResources, languages, teachingStage, tag, onButtonClicked, contrast }) {
  return (
    <FilterSummaryPaper square elevation={4} contrast={contrast}>
      <div className="main">
        <h3 className="title">
          Resumo dos filtros selecionados
        </h3>
        <Grid container direction='column' spacing={2}>
          <Grid item>
            <Grid container direction='row' spacing={1} alignItems='center'>
              <Grid item className="subtitle">
                Componentes curriculares:
              </Grid>
              <Grid item>
                {
                  curriculumComponents.map((item) => {
                    return (
                      item.isChecked &&
                      <StyledChip contrast={contrast} key={new Date().toISOString() + item.value} size="small" label={item.exemplo} />
                    );

                  })
                }
              </Grid>
            </Grid>
          </Grid>
          <Grid item>
            <Grid container direction='row' spacing={1} alignItems='center'>
              <Grid item className="subtitle">
                Tipos de recursos:
              </Grid>
              <Grid item>
                {
                  typeOfResources.map((item) => {
                    return (
                      item.isChecked &&
                      <StyledChip contrast={contrast} key={new Date().toISOString() + item.value} size="small" label={item.exemplo} />
                    );
                  })
                }
              </Grid>
            </Grid>
          </Grid>
          <Grid item>
            <Grid container direction='row' spacing={1} alignItems='center'>
              <Grid item className="subtitle">
                Etapas de ensino:
              </Grid>
              <Grid item>
                {
                  teachingStage.map((item) => {
                    return (
                      item.isChecked &&
                      <StyledChip contrast={contrast} key={new Date().toISOString() + item.value} size="small" label={item.exemplo} />
                    );
                  })
                }
              </Grid>
            </Grid>
          </Grid>
          <Grid item>
            <Grid container direction='row' spacing={1} alignItems='center'>
              <Grid item className="subtitle">
                Idiomas:
            </Grid>
              <Grid item>
                {
                  languages.map((item) => {
                    return (
                      item.isChecked &&
                      <StyledChip contrast={contrast} key={new Date().toISOString() + item.value} size="small" label={item.exemplo} />
                    );
                  })
                }
              </Grid>
            </Grid>
          </Grid>
          <Grid item>
            <Grid container direction='row' spacing={1} alignItems='center'>
              <Grid item className="subtitle">
                Palavra chave:
            </Grid>
              <Grid item>
                {
                  tag &&
                  <StyledChip contrast={contrast} size="small" label={tag} />
                }
              </Grid>
            </Grid>
          </Grid>
          <Grid item>
            <Button contrast={contrast} variant="contained" onClick={onButtonClicked}>
              Aplicar filtro
            </Button>
          </Grid>
        </Grid>
      </div>
    </FilterSummaryPaper>
  )
}

const FilterSummaryPaper = styled(Paper)`
  margin-top: 5px;
  margin-bottom: 30px;
  border: ${props => props.contrast === "" ? 0 : "1px solid white"};
  
  .title{
    text-transform: uppercase;
    color: ${props => props.contrast === "" ? "#666" : "white"};
    font-weight: 500; 
  }

  .main{
    background-color: ${props => props.contrast === "" ? "#fff" : "black"};
    padding: 0.5em 1em;
  }

  .subtitle{
    color: ${props => props.contrast === "" ? "#666" : "white"};
  }
`
const Button = styled.button`
  background: ${props => props.contrast === "" ? "#ff7f00" : "black"};
  text-transform: uppercase;
  color: ${props => props.contrast === "" ? "white" : "yellow"};
  font-family: Roboto,sans-serif;
  font-size: 14px;
  font-weight: 500;
  height: 36px;
  border-radius: 3px;
  border: ${props => props.contrast === "" ? 0 : "1px solid white"};
  box-shadow: 0 2px 5px 0 rgba(0,0,0,.26);
  display: inline-block;
  position: relative;
  cursor: pointer;
  min-height: 36px;
  min-width: 88px;
  line-height: 36px;
  vertical-align: middle;
  -webkit-box-align: center;
  outline: none;
  text-align: center;
  padding: 0em 1em;
  white-space: nowrap;
  text-decoration: ${props => props.contrast === "" ? "none" : "underline"};
  :hover {
    background: ${props => props.contrast === "" ? "rgba(255, 127, 0,0.75)" : "rgba(255,255,0,0.24)"};
  }
  :active{
    transform: translateY(2px);
  }
`

const StyledChip = styled(Chip)`
  margin: 0.2em; 
  background-color: ${props => props.contrast === "" ? 0 : "black !important"};
  border: ${props => props.contrast === "" ? 0 : "1px solid white !important"};
  color: ${props => props.contrast === "" ? 0 : "white !important"};
`
