/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/
import React, { useContext, useState } from 'react';
import Modal from '@material-ui/core/Modal';
import Backdrop from '@material-ui/core/Backdrop';
import Fade from '@material-ui/core/Fade';
import styled from 'styled-components'
import SignUpContainer from './SignUpContainerFunction.js'
import { Store } from '../Store.js'
import { authentication } from './HelperFunctions/getAxiosConfig'
import Snackbar from '@material-ui/core/Snackbar';
import MuiAlert from '@material-ui/lab/Alert';
//import {postRequest} from './HelperFunctions/getAxiosConfig'

export function Alert(props) {
    return <MuiAlert elevation={6} variant="filled" {...props} />;
}

export default function SignUpModal(props) {
    const { state, dispatch } = useContext(Store)

    const [snackbarOpened, handleSnackbar] = useState(false)

    const handleCloseSnackbar = (event, reason) => {
        if (reason === 'clickaway') {
            return;
        }

        handleSnackbar(false);
    }

    function handleSuccess(data) {
        dispatch({
            type: 'USER_SIGNED_UP',
            userLoggedIn: !state.userIsLoggedIn,
            user: data.data
        })
        props.handleClose()
    }

    function handleError(error) {
        handleSnackbar(true)
    }

    const handleLoginInfo = (newLogin) => {
        const url = `/auth`
        const payload = {
            name: newLogin.name,
            email: newLogin.email,
            password: newLogin.password,
            password_confirmation: newLogin.senha //,
            // terms_of_service : true,
            // avatar: ""
        }
        authentication(url, payload, handleSuccess, handleError)
        //postRequest(url, payload, handleSuccess, (error) => {console.log(error)})
    }

    return (
        <>
            <Snackbar open={snackbarOpened} autoHideDuration={1000} onClose={handleCloseSnackbar}
                anchorOrigin={{ vertical: 'top', horizontal: 'right' }}
            >
                <Alert severity="error">Ocorreu um erro ao se conectar!</Alert>
            </Snackbar>
            <StyledModalSignUp
                aria-labelledby="transition-modal-title"
                aria-describedby="transition-modal-description"
                open={props.open}

                centered="true"
                onClose={props.handleClose}
                closeAfterTransition
                BackdropComponent={Backdrop}
                BackdropProps={{
                    timeout: 500,
                }}
            >
                <Fade in={props.open}>
                    <SignUpContainer
                        contrast={state.contrast}
                        handleClose={props.handleClose}
                        openLogin={props.openLogin}
                        handleLoginInfo={handleLoginInfo}
                    />
                </Fade>
            </StyledModalSignUp>
        </>
    )
}

const StyledModalSignUp = styled(Modal)`
    .djXaxP{
        margin : 0 !important;
    }

    display : flex;
    align-items: center;
    justify-content : center;
    text-align : center;
    padding : 10px !important;
    border-radius : 4px;

`
