/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React from 'react'
import styled from 'styled-components'
import { Carregados } from '../StyledComponents.js'
import Button from '@material-ui/core/Button';

export function ButtonsAreaRecurso(props) {
    return (
        <Carregados contrast={props.contrast}>
            <p className="total">
                {props.sliceLength} recursos carregados de {props.total}
            </p>

            {
                !props.end &&
                <React.Fragment>
                    <ButtonMostrarMaisRecurso contrast={props.contrast} onClick={() => props.showMore(4)}>
                        <span>MOSTRAR MAIS 4</span>
                    </ButtonMostrarMaisRecurso>
                    <ButtonMostrarTodos contrast={props.contrast} onClick={() => { props.showMore(20) }}>
                        <span>MOSTRAR MAIS 20</span>
                    </ButtonMostrarTodos>
                </React.Fragment>
            }

        </Carregados>
    )
}

export function ButtonsAreaColecao(props) {
    return (
        <Carregados contrast={props.contrast}>
            <p className="total">
                {props.sliceLength} coleções carregadas de {props.total}
            </p>
            {
                !props.end &&
                <React.Fragment>
                    <ButtonMostrarMaisColecao contrast={props.contrast} onClick={() => { props.showMore(4) }}>
                        <span>MOSTRAR MAIS 4</span>
                    </ButtonMostrarMaisColecao>

                    <ButtonMostrarTodos contrast={props.contrast} onClick={() => { props.showMore(20) }}>
                        <span>MOSTRAR MAIS 20</span>
                    </ButtonMostrarTodos>
                </React.Fragment>
            }
        </Carregados>
    )
}

export function ButtonsAreaRede(props) {
    return (
        <Carregados contrast={props.contrast}>
            <p className="total">
                {props.sliceLength} usuários carregados {props.total}
            </p>

            {
                !props.end &&
                <React.Fragment>
                    <ButtonMostrarMaisRede contrast={props.contrast} onClick={() => { props.showMore(4) }}>
                        <span>MOSTRAR MAIS 4</span>
                    </ButtonMostrarMaisRede>

                    <ButtonMostrarTodos contrast={props.contrast} onClick={() => { props.showMore(20) }}>
                        <span>MOSTRAR MAIS 20</span>
                    </ButtonMostrarTodos>
                </React.Fragment>
            }

        </Carregados>
    )
}

const ButtonMostrarTodos = styled(Button)`
    &:hover {
        background-color: ${props => props.contrast === "" ? "#d5d5d5 !important" : "rgba(255,255,0,0.24) !important"};
    }
    height : 36px !important;
    padding-left : 16px !important;
    padding-right : 16px !important;
    font-weight : 500 !important;
    border-radius : 3px !important;
    color: ${props => props.contrast === "" ? "#666 !important" : "yellow !important"};
    text-decoration: ${props => props.contrast === "" ? "none" : "underline !important"};
    background-color: ${props => props.contrast === "" ? "#e8e8e8 !important" : "black !important"};
    border: ${props => props.contrast === "" ? 0 : "1px solid white !important"};
    min-width : 88px !important;
    height : 36px !important;
`

const ButtonMostrarMaisRede = styled(Button)`
    &:hover {
        background-color: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
    color: ${props => props.contrast === "" ? "#fff !important" : "yellow !important"};
    text-decoration: ${props => props.contrast === "" ? "none" : "underline !important"};
    background-color: ${props => props.contrast === "" ? "#00bcd4 !important" : "black !important"};
    border: ${props => props.contrast === "" ? 0 : "1px solid white !important"};
    font-size: 14px !important;
    font-weight: 500 !important;
    height: 36px !important;
    border-radius: 3px !important;
    padding-left: 16px !important;
    padding-right: 16px !important;
    box-shadow: 0 2px 5px 0 rgba(0,0,0,.26) !important;
    outline : none !important;
    min-width : 88px !important;
    vertical-align : middle !important;
    margin : 6px 8px !important;
    text-decoration : none !important;
`

export const ButtonMostrarMaisColecao = styled(Button)`
    &:hover {
        background-color: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
    color: ${props => props.contrast === "" ? "#fff !important" : "yellow !important"};
    text-decoration: ${props => props.contrast === "" ? "none" : "underline !important"};
    background-color: ${props => props.contrast === "" ? "#503096 !important" : "black !important"};
    border: ${props => props.contrast === "" ? 0 : "1px solid white !important"};
    font-size: 14px !important;
    font-weight: 500 !important;
    height: 36px !important;
    border-radius: 3px !important;
    padding-left: 16px !important;
    padding-right: 16px !important;
    box-shadow: 0 2px 5px 0 rgba(0,0,0,.26) !important;
    outline : none !important;
    min-width : 88px !important;
    vertical-align : middle !important;
    margin : 6px 8px !important;
    text-decoration : none !important;
`

export const ButtonMostrarMaisRecurso = styled(Button)`
    &:hover {
        background-color: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
    color: ${props => props.contrast === "" ? "#fff !important" : "yellow !important"};
    text-decoration: ${props => props.contrast === "" ? "none" : "underline !important"};
    background-color: ${props => props.contrast === "" ? "#ff7f00 !important" : "black !important"};
    border: ${props => props.contrast === "" ? 0 : "1px solid white !important"};
    font-size: 14px !important;
    font-weight: 500 !important;
    height: 36px !important;
    border-radius: 3px !important;
    padding-left: 16px !important;
    padding-right: 16px !important;
    box-shadow: 0 2px 5px 0 rgba(0,0,0,.26) !important;
    outline : none !important;
    min-width : 88px !important;
    vertical-align : middle !important;
    margin : 6px 8px !important;
    text-decoration : none !important;
`
